import 'dart:developer';
import 'dart:ffi';
import 'dart:typed_data';

import '../utils/leb128.dart';
import '../utils/ser_de.dart';
import 'findex.dart';

class UidAndValue {
  Uint8List uid;
  Uint8List value;

  UidAndValue(this.uid, this.value) {
    if (uid.lengthInBytes != 32) {
      throw FindexException(
        "`uid` should be of length 32. Actual length is ${uid.lengthInBytes} bytes.",
      );
    }
  }

  static List<UidAndValue> deserialize(Uint8List bytes) {
    List<UidAndValue> values = [];

    // Get number of elements in input
    Iterator<int> iterator = bytes.iterator;
    final numItems = Leb128.decodeUnsigned(iterator);
    if (numItems == 0) {
      return [];
    }

    for (int idx = 0; idx < numItems; idx++) {
      // Get fixed-size UID
      final key = SerDe.copyFromIterator(iterator, uidLength);
      // Get value
      final value =
          SerDe.copyFromIterator(iterator, Leb128.decodeUnsigned(iterator));

      values.add(UidAndValue(key, value));
    }

    return values;
  }

  static int serializeToList(Uint8List output, List<UidAndValue> values) {
    log("serialize: output: $output");
    if (output.isEmpty) {
      throw Exception("Unable to serialize: output length value is 0");
    }
    try {
      final numItems = Leb128.encodeUnsigned(values.length);
      output.setAll(0, numItems);

      var idx = numItems.length;
      for (var entry in values) {
        idx = SerDe.write(output, idx, entry.uid);
        idx = SerDe.writeVector(output, idx, entry.value);
      }

      return idx;
    } catch (e, stacktrace) {
      log("Exception during UidAndValue serialize $e $stacktrace");
      return 0;
    }
  }

  static int serialize(Pointer<UnsignedChar> outputPointer,
      Pointer<UnsignedInt> outputLength, List<UidAndValue> values) {
    if (outputLength.value == 0) {
      throw Exception("Unable to serialize: output length value is 0");
    }
    var output = outputPointer.cast<Uint8>().asTypedList(outputLength.value);

    final length = serializeToList(output, values);
    outputLength.value = length;
    return length;
  }
}
